@@ -180,6 +180,8 @@ def fork_isolation(f):
     # sys.exit() can't be used here, because nose catches all exceptions,
     # including SystemExit
 
+    # pylint:disable=consider-using-sys-exit
+
     @functools.wraps(f)
     def wrapper(*args, **kwargs):
         readfd, writefd = os.pipe()
@@ -212,7 +214,6 @@ def fork_isolation(f):
             os.close(writefd)
             with os.fdopen(readfd, 'rb') as fp:
                 msg = fp.read()
-            msg = msg
             if not isinstance(msg, str):
                 msg = msg.decode('UTF-8')
             msg = msg.rstrip('\n')
@@ -226,6 +227,8 @@ def fork_isolation(f):
             else:
                 raise RuntimeError('unexpected isolated process status {0}'.format(status))
 
+    # pylint:enable=consider-using-sys-exit
+
     return wrapper
 
 @contextlib.contextmanager
